pynmet
============


O pynmet é um pacote para obtenção automática de dados das estações automáticas do [INMET](http://www.inmet.gov.br/portal/index.php?r=estacoes/estacoesautomaticas)


Documentação
=============

A documentação está disponível em https://sehnem.gitlab.io/pynmet/.


Instalação
============

O pynmet é compatível apenas com Python 3 e pode ser instalado pelo pip por meio do comando

pip install pynmet



License
=======

GPLv3
